@@ -1,6 +1,5 @@
-"progress" <-
-function (value, max.value = NULL, progress.bar = FALSE, char = "|",
-	init = (value == 0), console = TRUE, gui = TRUE)
+progress <- function (value, max.value = NULL, progress.bar = FALSE, char = "|",
+init = (value == 0), console = TRUE, gui = TRUE)
 {
 	if (!is.numeric(value))
 		stop("'value' must be numeric!")
@@ -10,15 +9,15 @@ function (value, max.value = NULL, progress.bar = FALSE, char = "|",
 	} else percent <- FALSE
 	if (!is.numeric(max.value))
 		stop("'max.value' must be numeric or NULL!")
-	# If value is higher than max.value, we erase the message
+	## If value is higher than max.value, we erase the message
 	erase.only <- (value > max.value)
-	# Get the saved data associated with this function
+	## Get the saved data associated with this function
 	CmdProgress <- getTemp(".progress", default = list(), mode = "list")
 
 	if (console & progress.bar) {
-		# The progress bar consists in two lines:
-		# first is a "scale" (only drawn when init == TRUE),
-		# second is filled with char according to the actual progression
+		## The progress bar consists in two lines:
+		## first is a "scale" (only drawn when init == TRUE),
+		## second is filled with char according to the actual progression
 		if (erase.only) {
 			cat ("\n")
 			CmdProgress$pos <- NULL
@@ -32,7 +31,7 @@ function (value, max.value = NULL, progress.bar = FALSE, char = "|",
 					scalebar <- " 0%---------25%---------50%---------75%--------100%\n"
 					CmdProgress$Scale <- 2
 				} else {
-					# Calculate best scale
+					## Calculate best scale
 					w <- getOption("width") - l1
 					CmdProgress$Scale <- (max.value %/% w) + 1
 					sl <- round(max.value / CmdProgress$Scale)
@@ -55,12 +54,12 @@ function (value, max.value = NULL, progress.bar = FALSE, char = "|",
 				cat(rep(as.character(char[1]), pos2 - pos1))
 			}
 		}
-		# Under Windows or MacOS, make sure the message is actualized
+		## Under Windows or MacOS, make sure the message is actualized
 		flush.console()
 	} else if (console & !progress.bar) {
-		# A progress indicator in the R console
-		# We work only with integer part of the values
-		# and transform them into strings of same length
+		## A progress indicator in the R console
+		## We work only with integer part of the values
+		## and transform them into strings of same length
 		max.value <- as.character(round(max.value))
 		l <- nchar(max.value)
 		value <- formatC(round(value), width = l)
@@ -70,13 +69,13 @@ function (value, max.value = NULL, progress.bar = FALSE, char = "|",
 		l2 <- nchar(msg2)
 		l3 <- def(CmdProgress$msglength, 0, mode = "numeric", length = 1)
 		if (l3 < 0) l3 <- 0
-		CmdProgress$msglength <- NULL	# Avoid using twice same data
+		CmdProgress$msglength <- NULL  # Avoid using twice same data
 		backspaces <- paste(rep("\8", l3), collapse = "")
 		if (erase.only) {
 			message <- ""
 			cat(backspaces, rep(" ", l3), sep = "")
 		} else {
-			# Treatment is different if it is 'x%' or 'x on y' display type
+			## Treatment is different if it is 'x%' or 'x on y' display type
 			if (percent) {
 				message <- paste(msg1, " ", value, "%  ", sep = "",
 					collapse = "")
@@ -88,15 +87,15 @@ function (value, max.value = NULL, progress.bar = FALSE, char = "|",
 		cat(backspaces, message, sep = "")
 		CmdProgress$msglength <- nchar(message)
 		assignTemp(".progress", CmdProgress)
-		# Under Windows or MacOS, make sure the message is actualized
+		## Under Windows or MacOS, make sure the message is actualized
 		flush.console()
 	}
 
-	# An additional, graphical display of progression may be implemented too
-	# using custom functions as items in .progress in TempEnv... Here we look
-	# for and trigger them...
+	## An additional, graphical display of progression may be implemented too
+	## using custom functions as items in .progress in TempEnv... Here we look
+	## for and trigger them...
 	if (gui && length(CmdProgress) > 1) {
-		# Execute each item of the list that is a function
+		## Execute each item of the list that is a function
 		for (i in 1:length(CmdProgress))
 			if (mode(CmdProgress[[i]]) == "function")
 				CmdProgress[[i]](value, max.value)
